EspNowError

Enum EspNowError 

pub enum EspNowError {
    Error(Error),
    SendFailed,
    DuplicateInstance,
    Initialization(WifiError),
}
Available on crate features esp-now and unstable only.
Common errors that can occur while using ESP-NOW driver.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Error(Error)

Internal Error: {0}.



SendFailed

Failed to send an ESP-NOW message.



DuplicateInstance

Attempt to create EspNow instance twice.



Initialization(WifiError)

Initialization error: {0}.