pub struct PeerCount {
pub total_count: i32,
pub encrypted_count: i32,
}Available on crate features
esp-now and unstable only.Expand description
Holds the count of peers in an ESP-NOW communication context.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields
total_count: i32The total number of peers.
encrypted_count: i32The number of encrypted peers.